==> bobplates_0.15.12.zip: bobplates_0.15.12/prototypes/item/gems.lua <==
data:extend(
{
  {
    type = "item",
    name = "gem-ore",
    icon = "__bobplates__/graphics/icons/ore/gem-ore.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "a-0",
    stack_size = 200
  },

  {
    type = "item",
    name = "ruby-ore",
    icon = "__bobplates__/graphics/icons/gems/ruby-ore.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "a-1",
    stack_size = 100
  },
  {
    type = "item",
    name = "sapphire-ore",
    icon = "__bobplates__/graphics/icons/gems/sapphire-ore.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "b-1",
    stack_size = 100
  },
  {
    type = "item",
    name = "emerald-ore",
    icon = "__bobplates__/graphics/icons/gems/emerald-ore.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "c-1",
    stack_size = 100
  },
  {
    type = "item",
    name = "amethyst-ore",
    icon = "__bobplates__/graphics/icons/gems/amethyst-ore.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "d-1",
    stack_size = 100
  },
  {
    type = "item",
    name = "topaz-ore",
    icon = "__bobplates__/graphics/icons/gems/topaz-ore.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "e-1",
    stack_size = 100
  },
  {
    type = "item",
    name = "diamond-ore",
    icon = "__bobplates__/graphics/icons/gems/diamond-ore.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "f-1",
    stack_size = 100
  },

  {
    type = "item",
    name = "ruby-3",
    icon = "__bobplates__/graphics/icons/gems/ruby-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-raw",
    order = "a-3",
    stack_size = 100
  },
  {
    type = "item",
    name = "sapphire-3",
    icon = "__bobplates__/graphics/icons/gems/sapphire-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-raw",
    order = "b-3",
    stack_size = 100
  },
  {
    type = "item",
    name = "emerald-3",
    icon = "__bobplates__/graphics/icons/gems/emerald-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-raw",
    order = "c-3",
    stack_size = 100
  },
  {
    type = "item",
    name = "amethyst-3",
    icon = "__bobplates__/graphics/icons/gems/amethyst-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-raw",
    order = "d-3",
    stack_size = 100
  },
  {
    type = "item",
    name = "topaz-3",
    icon = "__bobplates__/graphics/icons/gems/topaz-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-raw",
    order = "e-3",
    stack_size = 100
  },
  {
    type = "item",
    name = "diamond-3",
    icon = "__bobplates__/graphics/icons/gems/diamond-3.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-raw",
    order = "f-3",
    stack_size = 100
  },

  {
    type = "item",
    name = "ruby-4",
    icon = "__bobplates__/graphics/icons/gems/ruby-4.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-cut",
    order = "a-4",
    stack_size = 100,
  },
  {
    type = "item",
    name = "sapphire-4",
    icon = "__bobplates__/graphics/icons/gems/sapphire-4.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-cut",
    order = "b-4",
    stack_size = 100,
  },
  {
    type = "item",
    name = "emerald-4",
    icon = "__bobplates__/graphics/icons/gems/emerald-4.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-cut",
    order = "c-4",
    stack_size = 100,
  },
  {
    type = "item",
    name = "amethyst-4",
    icon = "__bobplates__/graphics/icons/gems/amethyst-4.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-cut",
    order = "d-4",
    stack_size = 100,
  },
  {
    type = "item",
    name = "topaz-4",
    icon = "__bobplates__/graphics/icons/gems/topaz-4.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-cut",
    order = "e-4",
    stack_size = 100,
  },
  {
    type = "item",
    name = "diamond-4",
    icon = "__bobplates__/graphics/icons/gems/diamond-4.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-cut",
    order = "f-4",
    stack_size = 100,
  },

  {
    type = "item",
    name = "ruby-5",
    icon = "__bobplates__/graphics/icons/gems/ruby-5.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-polished",
    order = "a-5",
    stack_size = 100,
  },
  {
    type = "item",
    name = "sapphire-5",
    icon = "__bobplates__/graphics/icons/gems/sapphire-5.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-polished",
    order = "b-5",
    stack_size = 100,
  },
  {
    type = "item",
    name = "emerald-5",
    icon = "__bobplates__/graphics/icons/gems/emerald-5.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-polished",
    order = "c-5",
    stack_size = 100,
  },
  {
    type = "item",
    name = "amethyst-5",
    icon = "__bobplates__/graphics/icons/gems/amethyst-5.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-polished",
    order = "d-5",
    stack_size = 100,
  },
  {
    type = "item",
    name = "topaz-5",
    icon = "__bobplates__/graphics/icons/gems/topaz-5.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-polished",
    order = "e-5",
    stack_size = 100,
  },
  {
    type = "item",
    name = "diamond-5",
    icon = "__bobplates__/graphics/icons/gems/diamond-5.png",
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-polished",
    order = "f-5",
    stack_size = 100,
  },
}
)

==> bobplates_0.16.2.zip: bobplates_0.16.2/prototypes/item/gems.lua <==
if not data.raw.item["gem-ore"] then
data:extend(
{
  {
    type = "item",
    name = "gem-ore",
    icon = "__bobplates__/graphics/icons/ore/gem-ore.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "a-0",
    stack_size = 200
  }
}
)
end

if not data.raw.item["ruby-ore"] then
data:extend(
{
  {
    type = "item",
    name = "ruby-ore",
    icon = "__bobplates__/graphics/icons/gems/ruby-ore.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "a-1",
    stack_size = 100
  }
}
)
end

if not data.raw.item["sapphire-ore"] then
data:extend(
{
  {
    type = "item",
    name = "sapphire-ore",
    icon = "__bobplates__/graphics/icons/gems/sapphire-ore.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "b-1",
    stack_size = 100
  }
}
)
end

if not data.raw.item["emerald-ore"] then
data:extend(
{
  {
    type = "item",
    name = "emerald-ore",
    icon = "__bobplates__/graphics/icons/gems/emerald-ore.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "c-1",
    stack_size = 100
  }
}
)
end

if not data.raw.item["amethyst-ore"] then
data:extend(
{
  {
    type = "item",
    name = "amethyst-ore",
    icon = "__bobplates__/graphics/icons/gems/amethyst-ore.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "d-1",
    stack_size = 100
  }
}
)
end

if not data.raw.item["topaz-ore"] then
data:extend(
{
  {
    type = "item",
    name = "topaz-ore",
    icon = "__bobplates__/graphics/icons/gems/topaz-ore.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "e-1",
    stack_size = 100
  }
}
)
end

if not data.raw.item["diamond-ore"] then
data:extend(
{
  {
    type = "item",
    name = "diamond-ore",
    icon = "__bobplates__/graphics/icons/gems/diamond-ore.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-ore",
    order = "f-1",
    stack_size = 100
  }
}
)
end


data:extend(
{
  {
    type = "item",
    name = "ruby-3",
    icon = "__bobplates__/graphics/icons/gems/ruby-3.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-raw",
    order = "a-3",
    stack_size = 100
  },
  {
    type = "item",
    name = "sapphire-3",
    icon = "__bobplates__/graphics/icons/gems/sapphire-3.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-raw",
    order = "b-3",
    stack_size = 100
  },
  {
    type = "item",
    name = "emerald-3",
    icon = "__bobplates__/graphics/icons/gems/emerald-3.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-raw",
    order = "c-3",
    stack_size = 100
  },
  {
    type = "item",
    name = "amethyst-3",
    icon = "__bobplates__/graphics/icons/gems/amethyst-3.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-raw",
    order = "d-3",
    stack_size = 100
  },
  {
    type = "item",
    name = "topaz-3",
    icon = "__bobplates__/graphics/icons/gems/topaz-3.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-raw",
    order = "e-3",
    stack_size = 100
  },
  {
    type = "item",
    name = "diamond-3",
    icon = "__bobplates__/graphics/icons/gems/diamond-3.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-raw",
    order = "f-3",
    stack_size = 100
  },

  {
    type = "item",
    name = "ruby-4",
    icon = "__bobplates__/graphics/icons/gems/ruby-4.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-cut",
    order = "a-4",
    stack_size = 100,
  },
  {
    type = "item",
    name = "sapphire-4",
    icon = "__bobplates__/graphics/icons/gems/sapphire-4.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-cut",
    order = "b-4",
    stack_size = 100,
  },
  {
    type = "item",
    name = "emerald-4",
    icon = "__bobplates__/graphics/icons/gems/emerald-4.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-cut",
    order = "c-4",
    stack_size = 100,
  },
  {
    type = "item",
    name = "amethyst-4",
    icon = "__bobplates__/graphics/icons/gems/amethyst-4.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-cut",
    order = "d-4",
    stack_size = 100,
  },
  {
    type = "item",
    name = "topaz-4",
    icon = "__bobplates__/graphics/icons/gems/topaz-4.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-cut",
    order = "e-4",
    stack_size = 100,
  },
  {
    type = "item",
    name = "diamond-4",
    icon = "__bobplates__/graphics/icons/gems/diamond-4.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-cut",
    order = "f-4",
    stack_size = 100,
  },

  {
    type = "item",
    name = "ruby-5",
    icon = "__bobplates__/graphics/icons/gems/ruby-5.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-polished",
    order = "a-5",
    stack_size = 100,
  },
  {
    type = "item",
    name = "sapphire-5",
    icon = "__bobplates__/graphics/icons/gems/sapphire-5.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-polished",
    order = "b-5",
    stack_size = 100,
  },
  {
    type = "item",
    name = "emerald-5",
    icon = "__bobplates__/graphics/icons/gems/emerald-5.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-polished",
    order = "c-5",
    stack_size = 100,
  },
  {
    type = "item",
    name = "amethyst-5",
    icon = "__bobplates__/graphics/icons/gems/amethyst-5.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-polished",
    order = "d-5",
    stack_size = 100,
  },
  {
    type = "item",
    name = "topaz-5",
    icon = "__bobplates__/graphics/icons/gems/topaz-5.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-polished",
    order = "e-5",
    stack_size = 100,
  },
  {
    type = "item",
    name = "diamond-5",
    icon = "__bobplates__/graphics/icons/gems/diamond-5.png",
    icon_size = 32,
    flags = {"goes-to-main-inventory"},
    subgroup = "bob-gems-polished",
    order = "f-5",
    stack_size = 100,
  },
}
)
